@@ -19,3 +19,5 @@ scroll_up   = sequence('S')
 scroll_down = sequence('T')
 save_cursor = sequence('s')
 load_cursor = sequence('u')
+show        = sequence('?25h')
+hide        = sequence('?25l')
